@@ -1,7 +1,7 @@
 """
 Type annotations for kafka service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/type_defs/)
 
 Usage::
 
@@ -93,20 +93,28 @@ __all__ = (
     "JmxExporterInfoTypeDef",
     "JmxExporterTypeDef",
     "KafkaVersionTypeDef",
+    "ListClusterOperationsRequestListClusterOperationsPaginateTypeDef",
     "ListClusterOperationsRequestRequestTypeDef",
     "ListClusterOperationsResponseTypeDef",
+    "ListClustersRequestListClustersPaginateTypeDef",
     "ListClustersRequestRequestTypeDef",
     "ListClustersResponseTypeDef",
+    "ListClustersV2RequestListClustersV2PaginateTypeDef",
     "ListClustersV2RequestRequestTypeDef",
     "ListClustersV2ResponseTypeDef",
+    "ListConfigurationRevisionsRequestListConfigurationRevisionsPaginateTypeDef",
     "ListConfigurationRevisionsRequestRequestTypeDef",
     "ListConfigurationRevisionsResponseTypeDef",
+    "ListConfigurationsRequestListConfigurationsPaginateTypeDef",
     "ListConfigurationsRequestRequestTypeDef",
     "ListConfigurationsResponseTypeDef",
+    "ListKafkaVersionsRequestListKafkaVersionsPaginateTypeDef",
     "ListKafkaVersionsRequestRequestTypeDef",
     "ListKafkaVersionsResponseTypeDef",
+    "ListNodesRequestListNodesPaginateTypeDef",
     "ListNodesRequestRequestTypeDef",
     "ListNodesResponseTypeDef",
+    "ListScramSecretsRequestListScramSecretsPaginateTypeDef",
     "ListScramSecretsRequestRequestTypeDef",
     "ListScramSecretsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -685,6 +693,14 @@ KafkaVersionTypeDef = TypedDict(
     },
 )
 
+ListClusterOperationsRequestListClusterOperationsPaginateTypeDef = TypedDict(
+    "ListClusterOperationsRequestListClusterOperationsPaginateTypeDef",
+    {
+        "ClusterArn": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListClusterOperationsRequestRequestTypeDef = TypedDict(
     "ListClusterOperationsRequestRequestTypeDef",
     {
@@ -703,6 +719,14 @@ ListClusterOperationsResponseTypeDef = TypedDict(
     },
 )
 
+ListClustersRequestListClustersPaginateTypeDef = TypedDict(
+    "ListClustersRequestListClustersPaginateTypeDef",
+    {
+        "ClusterNameFilter": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListClustersRequestRequestTypeDef = TypedDict(
     "ListClustersRequestRequestTypeDef",
     {
@@ -721,6 +745,15 @@ ListClustersResponseTypeDef = TypedDict(
     },
 )
 
+ListClustersV2RequestListClustersV2PaginateTypeDef = TypedDict(
+    "ListClustersV2RequestListClustersV2PaginateTypeDef",
+    {
+        "ClusterNameFilter": NotRequired[str],
+        "ClusterTypeFilter": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListClustersV2RequestRequestTypeDef = TypedDict(
     "ListClustersV2RequestRequestTypeDef",
     {
@@ -740,6 +773,14 @@ ListClustersV2ResponseTypeDef = TypedDict(
     },
 )
 
+ListConfigurationRevisionsRequestListConfigurationRevisionsPaginateTypeDef = TypedDict(
+    "ListConfigurationRevisionsRequestListConfigurationRevisionsPaginateTypeDef",
+    {
+        "Arn": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
     "ListConfigurationRevisionsRequestRequestTypeDef",
     {
@@ -758,6 +799,13 @@ ListConfigurationRevisionsResponseTypeDef = TypedDict(
     },
 )
 
+ListConfigurationsRequestListConfigurationsPaginateTypeDef = TypedDict(
+    "ListConfigurationsRequestListConfigurationsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListConfigurationsRequestRequestTypeDef = TypedDict(
     "ListConfigurationsRequestRequestTypeDef",
     {
@@ -775,6 +823,13 @@ ListConfigurationsResponseTypeDef = TypedDict(
     },
 )
 
+ListKafkaVersionsRequestListKafkaVersionsPaginateTypeDef = TypedDict(
+    "ListKafkaVersionsRequestListKafkaVersionsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListKafkaVersionsRequestRequestTypeDef = TypedDict(
     "ListKafkaVersionsRequestRequestTypeDef",
     {
@@ -792,6 +847,14 @@ ListKafkaVersionsResponseTypeDef = TypedDict(
     },
 )
 
+ListNodesRequestListNodesPaginateTypeDef = TypedDict(
+    "ListNodesRequestListNodesPaginateTypeDef",
+    {
+        "ClusterArn": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListNodesRequestRequestTypeDef = TypedDict(
     "ListNodesRequestRequestTypeDef",
     {
@@ -810,6 +873,14 @@ ListNodesResponseTypeDef = TypedDict(
     },
 )
 
+ListScramSecretsRequestListScramSecretsPaginateTypeDef = TypedDict(
+    "ListScramSecretsRequestListScramSecretsPaginateTypeDef",
+    {
+        "ClusterArn": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListScramSecretsRequestRequestTypeDef = TypedDict(
     "ListScramSecretsRequestRequestTypeDef",
     {
